/**
 * @file
 * Javascript to generate/process checkout button.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  /**
   * Attaches the ePaycoCheckoutForm behavior.
   */
  Drupal.behaviors.ePaycoCheckoutForm = {
    attach: function (context) {
      var __self = this;
      var settings = drupalSettings.commerce_epayco || {};

      // Automatically opening modal if enabled, is not defined, or by clicking button.
      if ((typeof settings.auto_open !== 'boolean') || settings.auto_open) {
        __self.showPaymentModal(settings.key, settings.test, settings.checkout);
      }
      $(document).on('click', '.js--epayco-payment-button:not(.js--processing)', function (event) {
        $(this).addClass('js--processing');
        __self.showPaymentModal(settings.key, settings.test, settings.checkout);
      });
    },
    showPaymentModal: function (key, test, checkoutData) {
      // Let's open modal, if all needed variables are defined.
      if (
        typeof ePayco == 'object' &&
        typeof key == 'string' &&
        typeof test == 'boolean' &&
        typeof checkoutData == 'object'
      ) {
        // The ePayco handler.
        var ePaycoHandler = ePayco.checkout.configure({
          key: key,
          test: test
        });
        ePaycoHandler.onCloseModal = function () {
          $('.js--epayco-payment-button.js--processing').removeClass('js--processing');
        };
        ePaycoHandler.open(checkoutData);
      }
      else {
        console.log(Drupal.t('Insuficient or wrong data for ePayco.'));
      }
    }
  };

})(jQuery, Drupal, drupalSettings);
